@@ -96,6 +96,8 @@ extern crate rand;
 #[cfg(all(test, feature = "nightly"))]
 extern crate test;
 
+/// Re-export of generic-array.
+pub use generic_array;
 /// Re-export of typenum.
 pub use typenum;
 
